# coding: utf-8

import requests
import re

from .exceptions import BadResponse
from .utils import check_status_code


def get_balance(number, password):
    params = {'class': 'CStatWS', 'op': 'GetBalance', 'directcall': 1}
    response = requests.get('https://%s:%s@stat.myttk.ru/soap/'
                            % (number, password), params=params)
    check_status_code(response, 200)

    match = re.search(r"<result>(.*?)</result>", response.content)
    balance = match.group(1)

    if balance is None:
        raise BadResponse('Unable to get balance from XML', response)

    return float(balance)



# coding: utf-8

import requests
import re

from .exceptions import BadResponse
from .utils import check_status_code


def get_balance(number, password):
    s = requests.Session()

    response = s.get('https://login.tele2.ru/ssotele2/wap/auth/')
    check_status_code(response, 200)

    match = re.search(r'value="(.*?)" name="_csrf"', response.content)
    csrf_token = match.group(1)
    if csrf_token is None:
        raise BadResponse('CSRF token not found', response)

    data = dict(pNumber=number, password=password, _csrf=csrf_token)
    response = s.post(
        'https://login.tele2.ru/ssotele2/wap/auth/submitLoginAndPassword',
        data=data)
    check_status_code(response, 200)

    response = s.get('https://my.tele2.ru/main/tariffAndBalance')
    check_status_code(response, 200)

    balance = response.json().get('balance')
    if balance is not None:
        amount = balance.get('amount')
    if balance is None or amount is None:
        raise BadResponse('Unable to get balance amount from JSON', response)

    return float(amount.split()[0].replace(',', '.'))



#!/usr/bin/env python

import requests
import re

from .exceptions import BadResponse
from .utils import check_status_code


def get_balance(number, password):
    session = requests.Session()

    response = session.get('https://login.mts.ru/amserver/UI/Login')
    check_status_code(response, 401)

    csrf_token = re.search(r'name="csrf.sign" value="(.*?)"', response.content)

    if csrf_token is None:
        raise BadResponse('CSRF token not found', response)

    csrf_token = csrf_token.group(1)

    response = session.post('https://login.mts.ru/amserver/UI/Login?service=lk&goto=https://lk.ssl.mts.ru/',
                      data={'IDToken1': number,
                            'IDToken2': password,
                            'csrf.sign': csrf_token,
                        },
                      headers={
                          'Accept-Language': 'ru,en;q=0.8',
                      })
    check_status_code(response, 200)

    response = session.get('https://oauth.mts.ru/webapi-1.4/customers/@me')

    check_status_code(response, 200)

    data = response.json()
    relations = data['genericRelations']
    targets = [rel['target'] for rel in relations]
    accounts = [target for target in targets if target['@c'] == '.Account']

    if not accounts:
        raise RuntimeError('Account not found in the data response')

    balance = accounts[0].get('balance')

    if balance is None:
        raise BadResponse('Unable to get balance from JSON', response)

    return float(balance)



#!/usr/bin/env python

"""Mobile Balance.

Usage:
  mobile-balance <operator> --phone=<phone-number> --password=<password> [--bad-responses-dir=<bad-responses-dir]
  mobile-balance (-h | --help)
  mobile-balance --version

Options:
  -h --help                Show this screen.
  --version                Show version.
  --phone=<phone-number>  Mobile number without 8 or +7 prefix.
  --password=<password>    Password from personal profile at mobile operator's site.
  --bad-responses-dir=<bad-responses-dir> Directory to save bad responses to.

"""

import os
import sys
import time

from mobile_balance import mts, megafon, tele2, ttk, exceptions
from docopt import docopt
from pkg_resources import get_distribution


def main():
    arguments = docopt(__doc__, version='Mobile Balance %s'
                       % get_distribution('mobile_balance').version)
    operator_name = arguments['<operator>']
    mobile_operator = globals()[operator_name]
    try:
        print mobile_operator.get_balance(arguments['--phone'],
                                          arguments['--password'])
    except exceptions.BadResponse, e:
        print >> sys.stderr, e
        bad_responses_dir = arguments['--bad-responses-dir']
        if bad_responses_dir:
            bad_responses_dir = os.path.join(bad_responses_dir,
                                             operator_name)
            if not os.path.exists(bad_responses_dir):
                os.makedirs(bad_responses_dir)

            filename = os.path.join(bad_responses_dir,
                                    '{0}-{1}.html'.format(
                                        e.response.status_code,
                                        time.time()))
            with open(filename, 'w') as f:
                f.write(e.response.content)



# coding: utf-8

import requests
import re

from .exceptions import BadResponse
from .utils import check_status_code


def get_balance(number, password):
    s = requests.Session()

    response = s.get('https://lk.megafon.ru/login/')
    check_status_code(response, 200)
    
    csrf_token = re.search(r'name="CSRF" value="(.*?)"', response.content)
    
    if csrf_token is None:
        raise BadResponse('CSRF token not found', response)
        
    csrf_token = csrf_token.group(1)

    response = s.post('https://lk.megafon.ru/dologin/',
                      data={'j_username': number,
                            'j_password': password,
                            'CSRF': csrf_token,
                        })
    check_status_code(response, 200)
    
    if u'Требуется ввод цифрового кода' in response.text:
        raise BadResponse('CAPTCHA was shown', response)
    if u'Как получить пароль' in response.text:
        raise BadResponse('Bad password or login', response)

    response = s.get('https://lk.megafon.ru/')
    check_status_code(response, 200)
    
    content = response.content
    match = re.search(r'<div class="[^"]*ui-label-balance".*?((&minus;)?\d[\d, ]*|\d[\d, ]*).*?</div>',
                      content)

    if match is None:
        raise BadResponse('Balance not found', response)
        
    text = match.group(1)
    text = text.replace(' ', '') \
               .replace(',', '.') \
               .replace('&minus;', '-')
    return float(text)



from invoke import run, task

@task
def release():
    run('git push')
    run('git push --tags')
    run('python setup.py register')
    run('python setup.py sdist upload')
    run('python setup.py bdist_wheel upload')


@task
def serve_docs():
    from livereload import Server, shell

    build_command = 'sphinx-build -b html docs dist/docs'
    run(build_command)

    server = Server()
    server.watch('*.rst', shell(build_command))
    server.watch('docs/', shell(build_command))
    server.serve(root='dist/docs')


from .exceptions import BadResponse

def check_status_code(response, expected_code):
    result_code = response.status_code
    
    if result_code != expected_code:
        url = response.url
        method = response.request.method

        raise BadResponse(('{method} to {url} resulted '
                           'in {result_code} status code '
                           'instead of {expected_code}').format(
                               **locals()),
                          response)



#!/usr/bin/env python

from setuptools import setup

setup(
    name='mobile-balance',
    version='0.6.0',
    description='A set of utilities to retrive a balance from some Russian mobile operators.',
    author='Alexander Artemenko',
    author_email='svetlyak.40wt@gmail.com',
    url='https://github.com/svetlyak40wt/mobile-balance',
    packages=[
        'mobile_balance',
    ],
    entry_points={
        'console_scripts': [
            'mobile-balance = mobile_balance.main:main',
        ]
    },
    install_requires=[
        'requests<2.3.0',
        'docopt<0.7.0',
        'pyopenssl',
        'ndg-httpsclient',
        'pyasn1'
    ],
    license='BSD',
    zip_safe=True,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
    ],
    keywords='mobile, balance, utility'
)
